@@ -1,7 +1,7 @@
 package Code::Includable::Tree::FromStruct;
 
-our $DATE = '2016-03-26'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-03-29'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 sub new_from_struct {
     my $class = shift;
@@ -23,9 +23,9 @@ sub new_from_struct {
         $node = $instantiate->($wanted_class, \%attrs);
     } else {
         if (!$pass_attributes) {
-            $node->$wanted_class->$constructor();
+            $node = $wanted_class->$constructor;
             for (keys %attrs) {
-                $node->$_->($attrs{$_});
+                $node->$_($attrs{$_});
             }
         } elsif ($pass_attributes eq 'hash') {
             $node = $wanted_class->$constructor(%attrs);
@@ -79,7 +79,7 @@ Code::Includable::Tree::FromStruct - Routine to build tree object from data stru
 
 =head1 VERSION
 
-This document describes version 0.07 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-26.
+This document describes version 0.08 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-29.
 
 =for Pod::Coverage .+
 
