@@ -1,7 +1,7 @@
 package Role::TinyCommons::Tree::Node;
 
-our $DATE = '2016-03-26'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-03-29'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use Role::Tiny;
 
@@ -23,7 +23,7 @@ Role::TinyCommons::Tree::Node - Role for a tree node object
 
 =head1 VERSION
 
-This document describes version 0.07 of Role::TinyCommons::Tree::Node (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-26.
+This document describes version 0.08 of Role::TinyCommons::Tree::Node (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-29.
 
 =head1 DESCRIPTION
 
@@ -34,17 +34,19 @@ L<Role::TinyCommons::Tree::NodeMethods>.
 
 =head2 parent => obj
 
-This must be an accessor, i.e. it must be able to set parent attribute using:
+If you need to build a tree or connect nodes, then the method must accept an
+optional argument to set value:
 
  $obj->parent($parent)
 
 =head2 children => list of obj|arrayref of obj
 
-This must be an accessor, i.e. it must be able to set children attribute using:
+If you need to build a tree or connect nodes, then the method must accept an
+optional argument to set value:
 
- $obj->children([$child1, ...])
+ $obj->children(\@children)
 
-But for flexibility, it is allowed to return arrayref or list.
+For flexibility, it is allowed to return arrayref or list of children nodes.
 
 =head1 HOMEPAGE
 
